Affiliated packages — Scikit-HEP 0.0.1 documentation

# Affiliated packages

We take the good concept of an Affiliated package from the Astropy project. An affiliated package is a Python package that is not part of the scikit-hep core package but is related to, and seen as part of, the Scikit-HEP project and community.

Affiliated packages are being identified and the community is most welcome to get in touch.

## List of affiliated packages

- numpythia: interface between Pythia and NumPy.
- pyjet: interface between FastJet and NumPy.
- uproot: minimalist ROOT I/O in pure Python and Numpy.
- root_numpy: interface between ROOT and NumPy.
- root_pandas: module for conveniently loading/saving ROOT files as pandas DataFrames.